==> qt6-declarative-6.5.3-1-aarch64.pkg.tar.xz: usr/include/qt6/QtQuickDialogs2Utils/qtquickdialogs2utilsexports.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <QtCore/qglobal.h>

#ifndef QTQUICKDIALOGS2UTILSEXPORTS_H
#define QTQUICKDIALOGS2UTILSEXPORTS_H

#if defined(QT_SHARED) || !defined(QT_STATIC)
#  if defined(QT_BUILD_QUICKDIALOGS2UTILS_LIB)
#    define Q_QUICKDIALOGS2UTILS_EXPORT Q_DECL_EXPORT
#  else
#    define Q_QUICKDIALOGS2UTILS_EXPORT Q_DECL_IMPORT
#  endif
#else
#  define Q_QUICKDIALOGS2UTILS_EXPORT
#endif

#if !defined(QT_BUILD_QUICKDIALOGS2UTILS_LIB) && !defined(QT_STATIC)
/* outside library -> inline decl + defi */
/* static builds treat everything as part of the library, so they never inline */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) inline
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) 1
#elif defined(QT_QUICKDIALOGS2UTILS_BUILD_REMOVED_API)
/* inside library, inside removed_api.cpp:
 * keep deprecated API -> non-inline decl;
 * remove deprecated API -> inline decl;
 * definition is always available */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) 1
#else
/* inside library, outside removed_api.cpp:
 * keep deprecated API -> non-inline decl, no defi;
 * remove deprecated API -> inline decl, defi */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, 1, 0)
#endif

#ifdef QT_QUICKDIALOGS2UTILS_BUILD_REMOVED_API
#  define QT_QUICKDIALOGS2UTILS_REMOVED_SINCE(major, minor) QT_DEPRECATED_SINCE(major, minor)
#else
#  define QT_QUICKDIALOGS2UTILS_REMOVED_SINCE(major, minor) 0
#endif

#endif // QTQUICKDIALOGS2UTILSEXPORTS_H

==> qt6-declarative-6.9.1-2-aarch64.pkg.tar.xz: usr/include/qt6/QtQuickDialogs2Utils/qtquickdialogs2utilsexports.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTQUICKDIALOGS2UTILSEXPORTS_H
#define QTQUICKDIALOGS2UTILSEXPORTS_H

#include <QtCore/qcompilerdetection.h>
#include <QtCore/qtconfigmacros.h> // Q_QUICKDIALOGS2UTILS_EXPORT
#include <QtCore/qtdeprecationmarkers.h> // QT_IF_DEPRECATED_SINCE

#if defined(QT_SHARED) || !defined(QT_STATIC)
#  if defined(QT_BUILD_QUICKDIALOGS2UTILS_LIB)
#    define Q_QUICKDIALOGS2UTILS_EXPORT Q_DECL_EXPORT
#  else
#    define Q_QUICKDIALOGS2UTILS_EXPORT Q_DECL_IMPORT
#  endif
#else
#  define Q_QUICKDIALOGS2UTILS_EXPORT
#endif

#if !defined(QT_BUILD_QUICKDIALOGS2UTILS_LIB) && !defined(QT_STATIC)
/* outside library -> inline decl + defi */
/* static builds treat everything as part of the library, so they never inline */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) inline
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) 1
#elif defined(QT_QUICKDIALOGS2UTILS_BUILD_REMOVED_API)
/* inside library, inside removed_api.cpp:
 * keep deprecated API -> non-inline decl;
 * remove deprecated API -> inline decl;
 * definition is always available */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) 1
#else
/* inside library, outside removed_api.cpp:
 * keep deprecated API -> non-inline decl, no defi;
 * remove deprecated API -> inline decl, defi */
#  define QT_QUICKDIALOGS2UTILS_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_QUICKDIALOGS2UTILS_INLINE_IMPL_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, 1, 0)
#endif

#ifdef QT_QUICKDIALOGS2UTILS_BUILD_REMOVED_API
#  define QT_QUICKDIALOGS2UTILS_REMOVED_SINCE(major, minor) QT_DEPRECATED_SINCE(major, minor)
#else
#  define QT_QUICKDIALOGS2UTILS_REMOVED_SINCE(major, minor) 0
#endif

#endif // QTQUICKDIALOGS2UTILSEXPORTS_H
